pub struct WindowEnv<State: Clone> { /* private fields */ }Expand description
Manager for a Window
Implementations
Sourceimpl<T: Clone> WindowEnv<T>
impl<T: Clone> WindowEnv<T>
Sourcepub fn new(
window_config: WindowConfig<T>,
event_loop: &EventLoop<EventMessage>,
) -> Self
pub fn new( window_config: WindowConfig<T>, event_loop: &EventLoop<EventMessage>, ) -> Self
Setup the Window and related features
Sourcepub fn finish_render(&mut self)
pub fn finish_render(&mut self)
Flush and submit the canvas.
Sourcepub fn resize(&mut self, size: PhysicalSize<u32>)
pub fn resize(&mut self, size: PhysicalSize<u32>)
Resize the Window
Sourcepub fn run_on_setup(&mut self)
pub fn run_on_setup(&mut self)
Run the on_setup callback that was passed to the launch function
Sourcepub fn run_on_exit(&mut self)
pub fn run_on_exit(&mut self)
Run the on_exit callback that was passed to the launch function